@@ -24,7 +24,7 @@ from typing import Any, Dict, Optional, Union
 import torch
 from torch import is_tensor
 
-from pytorch_lightning.core.lightning import LightningModule
+import pytorch_lightning as pl
 from pytorch_lightning.loggers.base import LightningLoggerBase, rank_zero_experiment
 from pytorch_lightning.utilities import _module_available, rank_zero_only
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
@@ -124,7 +124,7 @@ class CometLogger(LightningLoggerBase):
             If neither ``api_key`` nor ``save_dir`` are passed as arguments.
     """
 
-    LOGGER_JOIN_CHAR = '-'
+    LOGGER_JOIN_CHAR = "-"
 
     def __init__(
         self,
@@ -135,8 +135,8 @@ class CometLogger(LightningLoggerBase):
         experiment_name: Optional[str] = None,
         experiment_key: Optional[str] = None,
         offline: bool = False,
-        prefix: str = '',
-        **kwargs
+        prefix: str = "",
+        **kwargs,
     ):
         if comet_ml is None:
             raise ImportError(
@@ -205,9 +205,7 @@ class CometLogger(LightningLoggerBase):
             if self.mode == "online":
                 if self._experiment_key is None:
                     self._experiment = CometExperiment(
-                        api_key=self.api_key,
-                        project_name=self._project_name,
-                        **self._kwargs,
+                        api_key=self.api_key, project_name=self._project_name, **self._kwargs
                     )
                     self._experiment_key = self._experiment.get_key()
                 else:
@@ -219,9 +217,7 @@ class CometLogger(LightningLoggerBase):
                     )
             else:
                 self._experiment = CometOfflineExperiment(
-                    offline_directory=self.save_dir,
-                    project_name=self._project_name,
-                    **self._kwargs,
+                    offline_directory=self.save_dir, project_name=self._project_name, **self._kwargs
                 )
         finally:
             if self._future_experiment_key is not None:
@@ -248,7 +244,7 @@ class CometLogger(LightningLoggerBase):
                 metrics[key] = val.cpu().detach()
 
         metrics_without_epoch = metrics.copy()
-        epoch = metrics_without_epoch.pop('epoch', None)
+        epoch = metrics_without_epoch.pop("epoch", None)
         metrics_without_epoch = self._add_prefix(metrics_without_epoch)
         self.experiment.log_metrics(metrics_without_epoch, step=step, epoch=epoch)
 
@@ -318,6 +314,6 @@ class CometLogger(LightningLoggerBase):
         state["_experiment"] = None
         return state
 
-    def log_graph(self, model: LightningModule, input_array=None) -> None:
+    def log_graph(self, model: "pl.LightningModule", input_array=None) -> None:
         if self._experiment is not None:
             self._experiment.set_model_graph(model)
