@@ -25,7 +25,7 @@ import torch
 from torch.utils.tensorboard import SummaryWriter
 from torch.utils.tensorboard.summary import hparams
 
-from pytorch_lightning.core.lightning import LightningModule
+import pytorch_lightning as pl
 from pytorch_lightning.core.saving import save_hparams_to_yaml
 from pytorch_lightning.loggers.base import LightningLoggerBase, rank_zero_experiment
 from pytorch_lightning.utilities import _OMEGACONF_AVAILABLE, rank_zero_only, rank_zero_warn
@@ -62,6 +62,9 @@ class TensorBoardLogger(LightningLoggerBase):
             directory for existing versions, then automatically assigns the next available version.
             If it is a string then it is used as the run-specific subdirectory name,
             otherwise ``'version_${version}'`` is used.
+        sub_dir: Sub-directory to group TensorBoard logs. If a sub_dir argument is passed
+            then logs are saved in ``/save_dir/version/sub_dir/``. Defaults to ``None`` in which
+            logs are saved in ``/save_dir/version/``.
         log_graph: Adds the computational graph to tensorboard. This requires that
             the user has defined the `self.example_input_array` attribute in their
             model.
@@ -72,8 +75,8 @@ class TensorBoardLogger(LightningLoggerBase):
             :class:`SummaryWriter` can be passed as keyword arguments in this logger.
 
     """
-    NAME_HPARAMS_FILE = 'hparams.yaml'
-    LOGGER_JOIN_CHAR = '-'
+    NAME_HPARAMS_FILE = "hparams.yaml"
+    LOGGER_JOIN_CHAR = "-"
 
     def __init__(
         self,
@@ -82,13 +85,15 @@ class TensorBoardLogger(LightningLoggerBase):
         version: Optional[Union[int, str]] = None,
         log_graph: bool = False,
         default_hp_metric: bool = True,
-        prefix: str = '',
-        **kwargs
+        prefix: str = "",
+        sub_dir: Optional[str] = None,
+        **kwargs,
     ):
         super().__init__()
         self._save_dir = save_dir
-        self._name = name or ''
+        self._name = name or ""
         self._version = version
+        self._sub_dir = sub_dir
         self._log_graph = log_graph
         self._default_hp_metric = default_hp_metric
         self._prefix = prefix
@@ -107,8 +112,7 @@ class TensorBoardLogger(LightningLoggerBase):
         """
         if self.name is None or len(self.name) == 0:
             return self.save_dir
-        else:
-            return os.path.join(self.save_dir, self.name)
+        return os.path.join(self.save_dir, self.name)
 
     @property
     def log_dir(self) -> str:
@@ -120,12 +124,20 @@ class TensorBoardLogger(LightningLoggerBase):
         # create a pseudo standard path ala test-tube
         version = self.version if isinstance(self.version, str) else f"version_{self.version}"
         log_dir = os.path.join(self.root_dir, version)
+        if isinstance(self.sub_dir, str):
+            log_dir = os.path.join(log_dir, self.sub_dir)
+        log_dir = os.path.expandvars(log_dir)
+        log_dir = os.path.expanduser(log_dir)
         return log_dir
 
     @property
     def save_dir(self) -> Optional[str]:
         return self._save_dir
 
+    @property
+    def sub_dir(self) -> Optional[str]:
+        return self._sub_dir
+
     @property
     @rank_zero_experiment
     def experiment(self) -> SummaryWriter:
@@ -141,7 +153,7 @@ class TensorBoardLogger(LightningLoggerBase):
         if self._experiment is not None:
             return self._experiment
 
-        assert rank_zero_only.rank == 0, 'tried to init log dirs in non global_rank=0'
+        assert rank_zero_only.rank == 0, "tried to init log dirs in non global_rank=0"
         if self.root_dir:
             self._fs.makedirs(self.root_dir, exist_ok=True)
         self._experiment = SummaryWriter(log_dir=self.log_dir, **self._kwargs)
@@ -149,9 +161,7 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @rank_zero_only
     def log_hyperparams(
-        self,
-        params: Union[Dict[str, Any], Namespace],
-        metrics: Optional[Dict[str, Any]] = None,
+        self, params: Union[Dict[str, Any], Namespace], metrics: Optional[Dict[str, Any]] = None
     ) -> None:
         """
         Record hyperparameters. TensorBoard logs with and without saved hyperparameters
@@ -191,7 +201,7 @@ class TensorBoardLogger(LightningLoggerBase):
 
     @rank_zero_only
     def log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None) -> None:
-        assert rank_zero_only.rank == 0, 'experiment tried to log from global_rank != 0'
+        assert rank_zero_only.rank == 0, "experiment tried to log from global_rank != 0"
 
         metrics = self._add_prefix(metrics)
 
@@ -206,11 +216,11 @@ class TensorBoardLogger(LightningLoggerBase):
                     self.experiment.add_scalar(k, v, step)
                 # todo: specify the possible exception
                 except Exception as ex:
-                    m = f'\n you tried to log {v} which is not currently supported. Try a dict or a scalar/tensor.'
+                    m = f"\n you tried to log {v} which is not currently supported. Try a dict or a scalar/tensor."
                     raise ValueError(m) from ex
 
     @rank_zero_only
-    def log_graph(self, model: LightningModule, input_array=None):
+    def log_graph(self, model: "pl.LightningModule", input_array=None):
         if self._log_graph:
             if input_array is None:
                 input_array = model.example_input_array
@@ -220,9 +230,10 @@ class TensorBoardLogger(LightningLoggerBase):
                 self.experiment.add_graph(model, input_array)
             else:
                 rank_zero_warn(
-                    'Could not log computational graph since the'
-                    ' `model.example_input_array` attribute is not set'
-                    ' or `input_array` was not given', UserWarning
+                    "Could not log computational graph since the"
+                    " `model.example_input_array` attribute is not set"
+                    " or `input_array` was not given",
+                    UserWarning,
                 )
 
     @rank_zero_only
@@ -259,7 +270,7 @@ class TensorBoardLogger(LightningLoggerBase):
         try:
             listdir_info = self._fs.listdir(root_dir)
         except OSError:
-            log.warning('Missing logger folder: %s', root_dir)
+            log.warning("Missing logger folder: %s", root_dir)
             return 0
 
         existing_versions = []
@@ -267,7 +278,7 @@ class TensorBoardLogger(LightningLoggerBase):
             d = listing["name"]
             bn = os.path.basename(d)
             if self._fs.isdir(d) and bn.startswith("version_"):
-                dir_ver = bn.split("_")[1].replace('/', '')
+                dir_ver = bn.split("_")[1].replace("/", "")
                 existing_versions.append(int(dir_ver))
         if len(existing_versions) == 0:
             return 0
