@@ -15,11 +15,10 @@ from typing import Any, Optional
 
 from torchmetrics import ROC as _ROC
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 class ROC(_ROC):
-
     @deprecated_metrics(target=_ROC)
     def __init__(
         self,
@@ -35,4 +34,4 @@ class ROC(_ROC):
         .. deprecated::
             Use :class:`~torchmetrics.ROC`. Will be removed in v1.5.0.
         """
-        _ = num_classes, pos_label, compute_on_step, dist_sync_on_step, process_group
+        void(num_classes, pos_label, compute_on_step, dist_sync_on_step, process_group)
