@@ -23,12 +23,16 @@ class LightningEnvironment(ClusterEnvironment):
     """
     The default environment used by Lightning for a single node or free cluster (not managed).
 
-    The master process must be launched by the user and Lightning will spawn new
-    worker processes for distributed training, either in a single node or across multiple nodes.
+    There are two modes the Lightning environment can operate with:
+
+    1.  The user only launches the main process by :code:`python train.py ...` with no additional environment variables
+        set. Lightning will spawn new worker processes for distributed training in the current node.
+    2.  The user launches all processes manually or with utilities like :code:`torch.distributed.launch`.
+        The appropriate environment variables need to be set, and at minimum :code:`LOCAL_RANK`.
 
     If the master address and port are not provided, the default environment will choose them
     automatically. It is recommended to use this default environment for single-node distributed
-    training as it provides the most convenient way to launch the training script.
+    training as it provides a convenient way to launch the training script.
     """
 
     def __init__(self):
@@ -38,7 +42,12 @@ class LightningEnvironment(ClusterEnvironment):
         self._world_size: int = 1
 
     def creates_children(self) -> bool:
-        return False
+        """
+        Returns whether the cluster creates the processes or not.
+        If at least :code:`LOCAL_RANK` is available as environment variable, Lightning assumes the user acts as the
+        process launcher/job scheduler and Lightning will not launch new processes.
+        """
+        return "LOCAL_RANK" in os.environ
 
     def master_address(self) -> str:
         return os.environ.get("MASTER_ADDR", "127.0.0.1")
